@@ -1,5 +1,7 @@
 from workos.audit_trail import AuditTrail
 from workos.directory_sync import DirectorySync
+from workos.passwordless import Passwordless
+from workos.portal import Portal
 from workos.sso import SSO
 
 
@@ -24,5 +26,17 @@ class Client(object):
             self._directory_sync = DirectorySync()
         return self._directory_sync
 
+    @property
+    def passwordless(self):
+        if not getattr(self, "_passwordless", None):
+            self._passwordless = Passwordless()
+        return self._passwordless
+
+    @property
+    def portal(self):
+        if not getattr(self, "_portal", None):
+            self._portal = Portal()
+        return self._portal
+
 
 client = Client()
