@@ -4,7 +4,10 @@ class ConfigurationException(Exception):
 
 # Request related exceptions
 class BaseRequestException(Exception):
-    def __init__(self, response, message=None):
+    def __init__(self, response, message=None, error=None):
+        super(BaseRequestException, self).__init__(message)
+
+        self.error = error
         self.extract_and_set_response_related_data(response)
 
         if message is not None:
@@ -22,6 +25,18 @@ class BaseRequestException(Exception):
         headers = response.headers
         self.request_id = headers.get("X-Request-ID")
 
+    def __str__(self):
+        message = self.message or "No message"
+        exception = "(message=%s" % message
+
+        if self.request_id is not None:
+            exception += ", request_id=%s" % self.request_id
+
+        if self.error is not None:
+            exception += ", error=%s" % self.error
+
+        return exception + ")"
+
 
 class AuthorizationException(BaseRequestException):
     pass
