@@ -7,7 +7,13 @@ import workos
 from workos.exceptions import ConfigurationException
 from workos.resources.sso import WorkOSProfile
 from workos.utils.connection_types import ConnectionType
-from workos.utils.request import RequestHelper, RESPONSE_TYPE_CODE, REQUEST_METHOD_POST
+from workos.utils.request import (
+    RequestHelper,
+    RESPONSE_TYPE_CODE,
+    REQUEST_METHOD_DELETE,
+    REQUEST_METHOD_GET,
+    REQUEST_METHOD_POST,
+)
 from workos.utils.validation import SSO_MODULE, validate_settings
 
 AUTHORIZATION_PATH = "sso/authorize"
@@ -17,6 +23,8 @@ TOKEN_PATH = "sso/token"
 
 OAUTH_GRANT_TYPE = "authorization_code"
 
+RESPONSE_LIMIT = 10
+
 
 class SSO(object):
     """Offers methods to assist in authenticating through the WorkOS SSO service."""
@@ -50,7 +58,7 @@ class SSO(object):
             str: URL to redirect a User to to begin the OAuth workflow with WorkOS
         """
         params = {
-            "client_id": workos.project_id,
+            "client_id": workos.client_id,
             "redirect_uri": redirect_uri,
             "response_type": RESPONSE_TYPE_CODE,
         }
@@ -69,6 +77,13 @@ class SSO(object):
         if state is not None:
             params["state"] = state
 
+        if workos.project_id is not None:
+            params["client_id"] = workos.project_id
+            warn(
+                "'project_id' is deprecated. Use 'client_id' instead.",
+                DeprecationWarning,
+            )
+
         prepared_request = Request(
             "GET",
             self.request_helper.generate_api_url(AUTHORIZATION_PATH),
@@ -90,12 +105,19 @@ class SSO(object):
             WorkOSProfile: WorkOSProfile object representing the User
         """
         params = {
-            "client_id": workos.project_id,
+            "client_id": workos.client_id,
             "client_secret": workos.api_key,
             "code": code,
             "grant_type": OAUTH_GRANT_TYPE,
         }
 
+        if workos.project_id is not None:
+            params["client_id"] = workos.project_id
+            warn(
+                "'project_id' is deprecated. Use 'client_id' instead.",
+                DeprecationWarning,
+            )
+
         response = self.request_helper.request(
             TOKEN_PATH, method=REQUEST_METHOD_POST, params=params
         )
@@ -109,7 +131,7 @@ class SSO(object):
         been promoted will enable Enterprise users of the domain to begin signing in via SSO.
 
         Args:
-            token (str): The token supplied via the response when a draft connection is created via 
+            token (str): The token supplied via the response when a draft connection is created via
             the WorkOS.js embed
 
         Returns:
@@ -143,3 +165,66 @@ class SSO(object):
             params=params,
             token=workos.api_key,
         )
+
+    def get_connection(self, connection):
+        """Gets details for a single Connection
+
+        Args:
+            connection (str): Connection unique identifier
+
+        Returns:
+            dict: Connection response from WorkOS.
+        """
+        return self.request_helper.request(
+            "connections/{connection}".format(connection=connection),
+            method=REQUEST_METHOD_GET,
+            token=workos.api_key,
+        )
+
+    def list_connections(
+        self,
+        connection_type=None,
+        domain=None,
+        organization_id=None,
+        limit=RESPONSE_LIMIT,
+        before=None,
+        after=None,
+    ):
+        """Gets details for existing Connections.
+
+        Args:
+            connection_type (ConnectionType): Authentication service provider descriptor. (Optional)
+            domain (str): Domain of a Connection. (Optional)
+            limit (int): Maximum number of records to return. (Optional)
+            before (str): Pagination cursor to receive records before a provided Connection ID. (Optional)
+            after (str): Pagination cursor to receive records after a provided Connection ID. (Optional)
+
+        Returns:
+            dict: Connections response from WorkOS.
+        """
+        params = {
+            "connection_type": connection_type,
+            "domain": domain,
+            "organization_id": organization_id,
+            "limit": limit,
+            "before": before,
+            "after": after,
+        }
+        return self.request_helper.request(
+            "connections",
+            method=REQUEST_METHOD_GET,
+            params=params,
+            token=workos.api_key,
+        )
+
+    def delete_connection(self, connection):
+        """Deletes a single Connection
+
+        Args:
+            connection (str): Connection unique identifier
+        """
+        return self.request_helper.request(
+            "connections/{connection}".format(connection=connection),
+            method=REQUEST_METHOD_DELETE,
+            token=workos.api_key,
+        )
