@@ -14,7 +14,7 @@ REQUIRED_SETTINGS_FOR_MODULE = {
     DIRECTORY_SYNC_MODULE: ["api_key",],
     PASSWORDLESS_MODULE: ["api_key",],
     PORTAL_MODULE: ["api_key",],
-    SSO_MODULE: ["api_key", "project_id",],
+    SSO_MODULE: ["api_key", "client_id",],
 }
 
 
@@ -23,9 +23,20 @@ def validate_settings(module_name):
         @wraps(fn)
         def wrapper(*args, **kwargs):
             missing_settings = []
-            for setting in REQUIRED_SETTINGS_FOR_MODULE[module_name]:
-                if not getattr(workos, setting, None):
-                    missing_settings.append(setting)
+
+            # Adding this to accept both client_id and project_id
+            # can remove once project_id is deprecated
+            if module_name == SSO_MODULE:
+                if not getattr(workos, "api_key", None):
+                    missing_settings.append("api_key")
+                if not getattr(workos, "client_id", None) and not getattr(
+                    workos, "project_id", None
+                ):
+                    missing_settings.append("client_id")
+            else:
+                for setting in REQUIRED_SETTINGS_FOR_MODULE[module_name]:
+                    if not getattr(workos, setting, None):
+                        missing_settings.append(setting)
 
             if missing_settings:
                 raise ConfigurationException(
